summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteaccountmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteaccountmanager.h')
-rw-r--r--kopete/libkopete/kopeteaccountmanager.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/libkopete/kopeteaccountmanager.h b/kopete/libkopete/kopeteaccountmanager.h
index a8163245..f1ba6443 100644
--- a/kopete/libkopete/kopeteaccountmanager.h
+++ b/kopete/libkopete/kopeteaccountmanager.h
@@ -196,11 +196,11 @@ signals:
* \brief An account has changed its onlinestatus
* Technically this monitors Account::myself() onlinestatus changes
* \param account Account which changed its onlinestatus
* \param oldtqStatus The online status before the change
* \param newtqStatus The new online status
*/
void accountOnlineStatusChanged(Kopete::Account *account,
- const Kopete::OnlineStatus &oldtqStatus, const Kopete::OnlineStatus &newtqStatus);
+ const Kopete::OnlineStatus &oldStatus, const Kopete::OnlineStatus &newStatus);
private:
/**
@@ -211,7 +211,7 @@ private:
private slots:
void slotPluginLoaded( Kopete::Plugin *plugin );
void slotAccountOnlineStatusChanged(Kopete::Contact *c,
- const Kopete::OnlineStatus &oldtqStatus, const Kopete::OnlineStatus &newtqStatus);
+ const Kopete::OnlineStatus &oldStatus, const Kopete::OnlineStatus &newStatus);
/**
* \internal
@@ -196,11 +196,11 @@ signals:
* Technically this monitors Account::myself() onlinestatus changes
* \param account Account which changed its onlinestatus
- * \param oldtqStatus The online status before the change
- * \param newtqStatus The new online status
+ * \param oldStatus The online status before the change
+ * \param newStatus The new online status
*/
void accountOnlineStatusChanged(Kopete::Account *account,